/* ipinfo.r */

/********************************************************************************/

!include <sculptor.h>
!include <http.h>
!include <www.h>

/********************************************************************************/
/*				Data															*/
/********************************************************************************/
. Here we define the structure of the http://deckofcardsapi.com/api response
!record response {
	ip,"IP",a64,,v
	hostname,"Hostname",a64,,v
	city,"City",a64,,v
	region,"Region",a64,,v
	country,"Country",a64,,v
	loc,"Localization",a64,,v
	org,"Organization",a64,,v
	postal,"Postal code",a64,,v
}

/********************************************************************************/
/*				Windows															*/
/********************************************************************************/

-window wintask at 134,26 {
	max_width = 937
	max_height = 803
	event = evWinTask
	style = WS_CLOSEBUTTON | WS_MAXBUTTON | WS_MINBUTTON
	data_font = "Arial@12"
	label_font = "Arial@12"
	title = "IP Information"

	+graphic graInfo at 38,30 {
		type = GT_RECTANGLE
		width = 685
		height = 719
	}

	+textbox txtIp at 85,70 {
		field = response.ip
		rows = 1
		height = 30
	}

	+button btnSearch at 784,49 {
		label = "&Search"
		style = WS_DEFAULT_BUTTON
		width = 100
		height = 50
		event = evSearch
	}

	+textbox txtHostname at 85,157 {
		field = response.hostname
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtCity at 85,244 {
		field = response.city
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtRegion at 85,331 {
		field = response.region
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtCountry at 85,418 {
		field = response.country
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtLoc at 85,505 {
		field = response.loc
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtOrg at 85,592 {
		field = response.org
		rows = 1
		height = 30
		mode = EM_READONLY
	}

	+textbox txtPostal at 85,679 {
		field = response.postal
		rows = 1
		height = 30
		mode = EM_READONLY
	}
}

/********************************************************************************/
/*				Definitions														*/
/********************************************************************************/

!define IPINFO_API_BASE	"http://ipinfo.io/"
	
/********************************************************************************/
/*				Code															*/
/********************************************************************************/

	fSetup()
	fMain()
	exit

/********************************************************************************/

!function fQueryData() {
	response.hostname = ""
	response.city = ""
	response.region = ""
	response.country = ""
	response.loc = ""
	response.org = ""
	response.postal = ""

	fQueryInfo()
}

/*------------------------------------------------------------------------------*/

!function fSetup() {

	fQueryData()

	. Create the window
	create wintask

	. Display data and enable/disable controls
	fDisplayResponse()
}

/*------------------------------------------------------------------------------*/

!function fMain() {

	dialog cancel=MAIN_FINISH

MAIN_FINISH:
	return
}

/*------------------------------------------------------------------------------*/

!function fDisplayResponse() {
	. Show all the information
	display wintask
}

/*------------------------------------------------------------------------------*/

!function fSendQuery(url) {
!temp status,,i4

	status = http_simple_send(url, METHOD_GET, 0, NULL, response)

	. Check errors
	if (status = -1) {
		error "HTTP error: " + sys.HttpErrorMessage
		return FALSE
	}
	if (status <> SC_OK) {
		error "HTTP error (" + tostr(status) + "): " + sys.HttpResponseMessage
		return FALSE
	}
	
	return TRUE
}

/*------------------------------------------------------------------------------*/

!function fSendAndDisplay(url) {
	if (fSendQuery(url) = TRUE) {
		fDisplayResponse()
	}
}

/*------------------------------------------------------------------------------*/
/*			Deck of Cards REST API												*/
/*------------------------------------------------------------------------------*/

. URL: http://ipinfo.io/${IP}
!function fQueryInfo() {
!temp url,,a255,,v

	url = IPINFO_API_BASE + response.ip

	fSendAndDisplay(url)
}

/*------------------------------------------------------------------------------*/
/*			Event functions														*/
/*------------------------------------------------------------------------------*/

!function evSearch(EventCode) {
	if (EventCode != EV_BUTTON_CLICKED) return

	fQueryData()
}

/*------------------------------------------------------------------------------*/

!function evWinTask(EventCode) {

	switch (EventCode) {
	case == EV_CLOSE:
		exit
	}
}

/********************************************************************************/
!chargrid OFF
/********************************************************************************/
